<?php

/**
 * collect content from all following pages from a defined start page onwards
 *
 * @module          content_collector
 * @author          Wolfgang Studer
 * @copyright       2015-2015 Wolfgang Studer
 * @link            www.LEPTON-cms.org
 * @license         GNU General Public License
 * @license_terms   please see info.php of this module
 * @version         $Id: 2.00.000 | 2015-11-29
 */

// include class.secure.php to protect this file and the whole CMS!
if ( defined('LEPTON_PATH') == TRUE ):	
	include(LEPTON_PATH.'/framework/class.secure.php');
else:
	$oneback = "../";
	$root = $oneback;
	$level = 1;
	while (($level < 10) && (!file_exists($root.'/framework/class.secure.php'))):
		$root .= $oneback;
		$level += 1;
	endwhile;
	
	if (file_exists($root.'/framework/class.secure.php')):
		include($root.'/framework/class.secure.php');
	else:
		trigger_error(sprintf("[ <b>%s</b> ] Can't include class.secure.php!", $_SERVER['SCRIPT_NAME']), E_USER_ERROR);
	endif;
endif;
// end include class.secure.php


// function to start list preparation
function build_list( $parent )
{
	// define globals
	global $database;
	global $admin;
	global $page_id;				// the current page

	global $pages;					// the target list containing the prepared data list
	global $MOD_CONTENT_COLLECTOR;		// the TEXT array

	global $start_from_page;		// the already selected pageID

 	// initialize previous page
 	$prev_page = '';

 	// get data to be shown in dropdown list
 	$query = 'SELECT p.link, p.page_title, p.page_id, p.level, p.template, p.visibility
					, p.viewing_groups, p.viewing_users, p.admin_groups, p.admin_users
				FROM ' . TABLE_PREFIX . 'pages p
				WHERE p.parent = ' . $parent . '
				ORDER BY p.level, p.position ASC';

	if ( $query_data = $database->query( $query )):
	
		while( $result = $query_data->fetchRow() ):
			// mark current page
			$curPage = '';
			if ( $result['page_id'] == $page_id ):
				$curPage = " *";
			endif;

			// set page key
			$page_key = "P" . $result['page_id'];

			// first create an entry for the page
			if (( empty( $pages ) == TRUE ) ||  ( array_key_exists( $page_key, $pages ) == FALSE )):

				// recursive call for subpages of previous page
				if ( empty( $prev_page ) == FALSE ):
					build_list( $prev_page );
				endif;
				$prev_page = $result['page_id'];

				// prepare PAGE line
				$valueArray = Array();
				$valueArray['disabled'] = '';
				$valueArray['selected'] = ( $result['page_id'] == $start_from_page ? 'selected="selected"' : '' );
				$valueArray['data']     = str_repeat("-- ", $result['level'] +1 )
										. $curPage . ' [' . sprintf( "%3d", $result['page_id'] ) . '] '
										. $result['page_title'];


				// disable pages and sections where permission is missing
				// logic copied from lepton/admins/pages/sections.php on v1.3.2
				$admin_groups = explode(',', $result['admin_groups']);
				$admin_users  = explode(',', $result['admin_users']);
				$has_permission = FALSE;
				foreach( $admin->get_groups_id() as $cur_gid):
					if ( in_array( $cur_gid, $admin_groups) == TRUE ):
						$has_permission = TRUE;
						break;
					endif;			
				endforeach;
				if ( $has_permission == FALSE ):
					if ( is_numeric( array_search( $admin->get_user_id(), $admin_users )) == TRUE ):
						$has_permission = TRUE;
					endif;			
				endif;
				$valueArray['PERMISSION'] = $has_permission;


				// check if refered section is on a visible page
					// return:	TRUE if page is visbible
					//			FALSE if page is not visible
				$valueArray['VISIBILITY'] = $admin->page_is_visible( $result );

				// highlight exceptions
				if ( $valueArray['PERMISSION'] == FALSE ):
					$valueArray['data']  .= ' ' . $MOD_CONTENT_COLLECTOR['MISSING_PERMISSION'];
					$valueArray['disabled'] = 'disabled="disabled"';

				elseif ( $result['visibility'] == 'deleted' ):
					$valueArray['data']  .= ' ' . $MOD_CONTENT_COLLECTOR['DELETED_PAGE'];
					$valueArray['disabled'] = 'disabled="disabled"';

				elseif ( $valueArray['VISIBILITY'] == FALSE ):
					$valueArray['data']  .= ' ' . $MOD_CONTENT_COLLECTOR['PAGE_NOT_VISIBLE'];
					$valueArray['disabled'] = 'disabled="disabled"';

				endif;


				// save value array into target array list
				$pages[ $page_key ] = $valueArray;
			endif;
		endwhile;
	endif;
	
	// recursive call for subpages of current page
	if ( empty( $prev_page ) == FALSE ):
		build_list( $prev_page );
	endif;
}

?>
