<?php

/**
 * collect content from all following pages from a defined start page onwards
 *
 * @module          content_collector
 * @author          Wolfgang Studer
 * @copyright       2015-2015 Wolfgang Studer
 * @link            www.LEPTON-cms.org
 * @license         GNU General Public License
 * @license_terms   please see info.php of this module
 * @version         $Id: 2.00.000 | 2015-11-29
 */

// include class.secure.php to protect this file and the whole CMS!
if ( defined('LEPTON_PATH') == TRUE ):	
	include(LEPTON_PATH.'/framework/class.secure.php');
else:
	$oneback = "../";
	$root = $oneback;
	$level = 1;
	while (($level < 10) && (!file_exists($root.'/framework/class.secure.php'))):
		$root .= $oneback;
		$level += 1;
	endwhile;
	
	if (file_exists($root.'/framework/class.secure.php')):
		include($root.'/framework/class.secure.php');
	else:
		trigger_error(sprintf("[ <b>%s</b> ] Can't include class.secure.php!", $_SERVER['SCRIPT_NAME']), E_USER_ERROR);
	endif;
endif;
// end include class.secure.php


// define list of invalid modules, see also section rules below
	$invalidModules = array();
	$invalidModules[] = "content_collector";	// new module name
	$invalidModules[] = "get_all_pages_content";	// old module name
	$invalidModules[] = "menu_link";


// define list of invalid pages
	// ['ATTRIBUTE']	= one of:
	//						- any field from table "pages"
	//						- 'PERMISSION' contains result of EDIT permissions check
	//						- 'VISIBILITY' contains result of $admin->page_is_visible()

	// ['VALUE'] 		= the corresponding value to be checked inside ['ATTRIBUTE'], see also COMPARE notes
	//					for 'PERMISSION' the VALUE can be TRUE or FALSE
	//					for 'VISIBILITY' the VALUE can be TRUE or FALSE

	// ['COMPARE'] 		= compares the VALUE with the attributes value, can be one of :
	//						'<>' or '!='	= not equal
	//						'<'				= less
	//						'<=				= less or equal
	//						'>'				= greater
	//						'>=' 			= greater or equal
	//						'IN'			= in an array (Value must then be an array)
	//						'BETWEEN'		= for numeric only: means > VALUE[0] AND < VALUE[1] (Value must then be an array with 2 elements)
	//						anything else	= equal
	//					for 'PERMISSION' the COMPARE can either be "=" for equal or anything else for not equal
	//					for 'VISIBILITY' the COMPARE can either be "=" for equal or anything else for not equal

	// ['ERROR'] 		= when rule match show an language dependend variable content behind the row

	// ['SELECTION']	= when rule match do one of :
	//						'DISABLED'		= show but disable the selection row
	//						'HIDE'			= do not list the selection row, automatically set SUBTREE = HIDE too
	//						anything else	= show and enable the selection row

	// ['SECTIONS']		= when rule match and page row is shown do one of :
	//						'HIDE'			= do not show sections of this page
	//						anything else	= show sections
	
	// ['SUBTREE']		= when rule match do one of :
	//						'HIDE'			= do not add subtree items in selection
	//						anything else	= add subtree items into selection
	
	$invalidPages = array();

	$invalidPages[] = array(  'ATTRIBUTE'	=> 'visibility'
							, 'VALUE'		=> 'deleted'
							, 'COMPARE'		=> '='
							, 'ERROR'		=> 'DELETED_PAGE'
							, 'SELECTION'	=> 'DISABLED'
							, 'SUBTREE'		=> 'HIDE'
							);

	$invalidPages[] = array(  'ATTRIBUTE'	=> 'menu'
							, 'VALUE'		=> $run_with_menu
							, 'COMPARE'		=> '!='
							, 'ERROR'		=> ''
							, 'SELECTION'	=> 'HIDE'
							, 'SUBTREE'		=> 'HIDE'
							);

	$invalidPages[] = array(  'ATTRIBUTE'	=> 'PERMISSION'
							, 'VALUE'		=> FALSE
							, 'COMPARE'		=> '='
							, 'ERROR'		=> ''
							, 'SELECTION'	=> 'HIDE'
							, 'SUBTREE'		=> 'HIDE'
							);

	$invalidPages[] = array(  'ATTRIBUTE'	=> 'VISIBILITY'
							, 'VALUE'		=> FALSE
							, 'COMPARE'		=> '='
							, 'ERROR'		=> ''
							, 'SELECTION'	=> 'HIDE'
							, 'SUBTREE'		=> 'HIDE'
							);


// define list of invalid sections
	// like for invalidPages with following differences:
	
	// ['ATTRIBUTE']	= one of:
	//						- any field from table "sections"
	//						- 'PERMISSION' contains result of EDIT permissions check on page
	//						- 'VISIBILITY' contains result of $admin->page_is_visible()

	// Note: section field names which exists also in "pages" table have a string "s_" in front!
	// Currently thats _page_id, s_position

	// ['SECTIONS']		= not supported

	// ['SUBTREE']		= not supported

	$invalidSections = array();

	$invalidSections[] = array(  'ATTRIBUTE'	=> 'visibility'
								, 'VALUE'		=> 'deleted'
								, 'COMPARE'		=> '='
								, 'ERROR'		=> 'DELETED_PAGE'
								, 'SELECTION'	=> 'DISABLED'
								, 'SUBTREE'		=> 'HIDE'
								);

	$invalidSections[] = array(  'ATTRIBUTE'	=> 'publ_start'
								, 'VALUE'		=> time()
								, 'COMPARE'		=> '>'
								, 'ERROR'		=> 'START_LATER'
								, 'SELECTION'	=> ''
								);

	$invalidSections[] = array(  'ATTRIBUTE'	=> 'publ_end'
								, 'VALUE'		=> array( 0, time() )
								, 'COMPARE'		=> 'BETWEEN'
								, 'ERROR'		=> 'END_PASSED'
								, 'SELECTION'	=> 'DISABLED'
								);

	$invalidSections[] = array(  'ATTRIBUTE'	=> 'module'
								, 'VALUE'		=> $invalidModules
								, 'COMPARE'		=> 'IN'
								, 'ERROR'		=> 'INVALID_MODULE'
								, 'SELECTION'	=> 'DISABLED'
								);

?>
