<?php

/**
 * collect content from all following pages from a defined start page onwards
 *
 * @module          content_collector
 * @author          Wolfgang Studer
 * @copyright       2015-2015 Wolfgang Studer
 * @link            www.LEPTON-cms.org
 * @license         GNU General Public License
 * @license_terms   please see info.php of this module
 * @version         $Id: 2.00.000 | 2015-11-29
 */

// include class.secure.php to protect this file and the whole CMS!
if ( defined('LEPTON_PATH') == TRUE ):	
	include(LEPTON_PATH.'/framework/class.secure.php');
else:
	$oneback = "../";
	$root = $oneback;
	$level = 1;
	while (($level < 10) && (!file_exists($root.'/framework/class.secure.php'))):
		$root .= $oneback;
		$level += 1;
	endwhile;
	
	if (file_exists($root.'/framework/class.secure.php')):
		include($root.'/framework/class.secure.php');
	else:
		trigger_error(sprintf("[ <b>%s</b> ] Can't include class.secure.php!", $_SERVER['SCRIPT_NAME']), E_USER_ERROR);
	endif;
endif;
// end include class.secure.php


// define variables used in here but nowwhere else
	$template_block = Array();
	$showSections = '';
	$subtreeParent = '';

// get all fields from table 'pages' & 'sections'
	$resultFields = array();
	$allFields = array();
	$database->get_all(
		"SHOW COLUMNS FROM `" . TABLE_PREFIX . "pages`",
		$allFields
	);
	foreach( $allFields as $fields ):
		$resultFields[] = 'p.' . $fields['Field'];
	endforeach;
	$allFields = array();
	$database->get_all(
		"SHOW COLUMNS FROM `" . TABLE_PREFIX . "sections`",
		$allFields
	);
	foreach( $allFields as $fields ):
		if ( in_array( 'p.' . $fields['Field'], $resultFields ) == FALSE ):
			$resultFields[] = 's.' . $fields['Field'];
		else:
			$resultFields[] = 's.' . $fields['Field'] . ' as s_' . $fields['Field'];
		endif;
	endforeach;


// define backend Path
	$backendPath = LEPTON_PATH . '/templates/' . DEFAULT_THEME . '/backend/content_collector/';

// load configuration
	$include = LEPTON_PATH . '/modules/content_collector/lib/lib.modify_select.config.php';
	include( $include );
	// load additional include on general level in frontend template folder if exists
	$include =  $backendPath . '/lib/lib.modify_select.config.php';
	if ( file_exists( $include ) == TRUE ):
		include( $include );
	endif;

// function to start list preparation
function build_list( $parent, $root = FALSE )
{
	// define globals
	global $database;
	global $admin;
	global $page_id;				// the current page
	global $section_id;				// the current section

	global $references;				// the target list containing the prepared data list
	global $invalidModules;			// a list of invalid modules
	global $MOD_CONTENT_COLLECTOR;		// the TEXT array for this module

	global $template_block;			// the array containing the block array from template info.php
	global $showSections;
	global $subtreeParent;
	global $resultFields;

	global $invalidPages;
	global $invalidSections;

	// init subtree Parent
	$subtreeParent = '';
	
	// get data to be shown in dropdown list
	$query = 'SELECT ' . implode(',', $resultFields )
			. ' FROM ' . TABLE_PREFIX . 'pages p
				LEFT OUTER JOIN ' . TABLE_PREFIX . 'sections s ON p.page_id = s.page_id';
	if ( $root == FALSE ):
		$query .= ' WHERE p.parent = ' . $parent;
	else:
		$query .= ' WHERE p.page_id = ' . $parent;
	endif;
	$query .=' ORDER BY p.level, p.position, s.position ASC';

	if ( $query_data = $database->query( $query )):
	
		while( $result = $query_data->fetchRow() ):
			// mark current page
			$curPage = '';
			if ( $result['page_id'] == $page_id ):
				$curPage = " *";
			endif;
			
			// set page key
			$page_key = "P" . $result['page_id'];

			// first create an entry for the page
			if (( empty( $references ) == TRUE ) ||  ( array_key_exists( $page_key, $references ) == FALSE )):
			
				// recursive call for subpages of previous page
				if ( empty( $subtreeParent ) == FALSE ):
					build_list( $subtreeParent, $root );
				endif;
				$subtreeParent = $result['page_id'];
				
				// get used template
				$template = DEFAULT_TEMPLATE;
				if ( empty( $result['template'] ) == FALSE ):
					$template = $result['template'];	// use page specific template
				endif;
				
				// get blocks defined in used template info.php
				if ( array_key_exists( $template, $template_block ) == FALSE ):
					$file_name = LEPTON_PATH . '/templates/' . $template . '/info.php';

					if ( file_exists( $file_name ) == TRUE ):
						// load the module addon
						require( $file_name );

						$template_block[ $template ]['block'] = $block;
						$template_block[ $template ]['name']  = $template_name;
					endif;
				endif;

				// prepare PAGE line
				$valueArray = Array();
				$valueArray['disabled'] = '';
				$valueArray['data']		= str_repeat("-- ", $result['level'] +1 )
										. $curPage
										. ' ['
											. sprintf( "%3d", $result['page_id'] )
											. ( $template == DEFAULT_TEMPLATE ? '' : ' | ' . $template_block[ $template ]['name'] )
										. '] '
										. $result['page_title'];


				// disable pages and sections where permission is missing
				// logic copied from lepton/admins/pages/sections.php on v1.3.2
				$admin_groups = explode(',', $result['admin_groups']);
				$admin_users  = explode(',', $result['admin_users']);
				$has_permission = FALSE;
				foreach( $admin->get_groups_id() as $cur_gid):
					if ( in_array( $cur_gid, $admin_groups) == TRUE ):
						$has_permission = TRUE;
						break;
					endif;			
				endforeach;
				if ( $has_permission == FALSE ):
					if ( is_numeric( array_search( $admin->get_user_id(), $admin_users )) == TRUE ):
						$has_permission = TRUE;
					endif;			
				endif;
				$valueArray['PERMISSION'] = $has_permission;

				// check if refered section is on a visible page
					// return:	TRUE if page is visbible
					//			FALSE if page is not visible
				$valueArray['VISIBILITY'] = $admin->page_is_visible( $result );

				// save page id of current section
				$valueArray['parent_key'] = $parent;

				// count number of processed sections on page
				$i = 0;
				if ( array_key_exists( $parent, $references ) == TRUE ):
					if ( array_key_exists( 'parent_count', $references[ $parent ] ) == TRUE ):
						$i = $references[ $parent ]['parent_count'];
					endif;
				endif;
				$references[ $parent ]['parent_count'] = $i + 1;

				// save value array into target array list
				$references[ $page_key ] = $valueArray;
			endif;


			// set default to load sections
			$showSections = TRUE;

			// do data validation
			dataValidation( $invalidPages, $page_key, $result );


			if (( $result['section_id'] > 0 ) && ( $showSections == TRUE )):
				// get used template
				$template = DEFAULT_TEMPLATE;
				if ( empty( $result['template'] ) == FALSE ):
					$template = $result['template'];	// use page specific template
				endif;
				
				// get block name
				$section_block = $result['block'];
				if ( empty( $section_block ) == TRUE ):
					$section_block = 0;
				endif;

				// save default data in target array
				$valueArray = Array();
				$valueArray['disabled'] = ( $result['section_id'] == $section_id ? 'disabled="disabled"' : '' );
				$valueArray['data']     = str_repeat("-- ", $result['level'] +3 ) . '>>'
										. $curPage
										. ' [' . $result['page_id'] . '] '
										. ' ==> ' . sprintf( "%3d", $result['section_id'] )
										. ' | ' . $result['module']
										. ' | ' . $section_block;
				if (( array_key_exists( $template, $template_block ) == TRUE )
				&&  ( array_key_exists( $section_block, $template_block[ $template ]['block'] ) == TRUE )):
					$valueArray['data'] .= ': ' . $template_block[ $template ]['block'][ $section_block ];
				endif;
				if (( empty($result['name']) == FALSE ) && ( $result['name'] != "no name" )):
					$valueArray['data'] .=  ' | ' . $result['name'];
				endif;

				// save page id of current section
				$valueArray['parent_key'] = $page_key;

				// count number of processed sections on page
				$i = 0;
				if ( array_key_exists( $parent, $references ) == TRUE ):
					if ( array_key_exists( 'parent_count', $references[ $parent ] ) == TRUE ):
						$i = $references[ $parent ]['parent_count'];
					endif;
				endif;
				$references[ $parent ]['parent_count'] = $i + 1;

				// save value array into targets array list
				$references[ "S" . $result['section_id'] ] = $valueArray;


				// do data validation
				dataValidation( $invalidSections, "S" . $result['section_id'], $result );


			endif;
		endwhile;
	endif;
	
	// recursive call for subpages of current page
	if ( empty( $subtreeParent ) == FALSE ):
		build_list( $subtreeParent, $root );
	endif;
}


// function to validate the data
function dataValidation( $validationRules = array(), $key = '', $result = array() )
{
	// define globals
	global $references;
	global $showSections;
	global $subtreeParent;
	global $MOD_CONTENT_COLLECTOR;

	// check and process page exceptions
	foreach ( $validationRules as $exception ):

		$attribute = $exception['ATTRIBUTE'];
		$compare = FALSE;

		switch ( $attribute ):
		case 'PERMISSION':
		case 'VISIBILITY':
			// check if exception matches
			if ((( $exception['COMPARE'] == "=" )
			&&	 ( $references[ $key ][ $attribute ] == $exception['VALUE'] ))
			||  (( $exception['COMPARE'] != "=" )
			&&	 ( $references[ $key ][ $attribute ] != $exception['VALUE'] ))):
				$compare = TRUE;
			endif;
			break;

		default:	// fields from table pages
			// check if field exists
			if ( array_key_exists( $attribute, $result ) != TRUE ):
				// field not exists, ignore this rule
				continue;
			endif;

			// check if value compares
			switch ( $exception['COMPARE'] ):
			case '<>':
			case '!=':
				if ( $result[ $attribute ] != $exception['VALUE'] ):
					$compare = TRUE;
				endif;
				break;

			case '<':
				if ( $result[ $attribute ] < $exception['VALUE'] ):
					$compare = TRUE;
				endif;
				break;

			case '<=':
				if ( $result[ $attribute ] <= $exception['VALUE'] ):
					$compare = TRUE;
				endif;
				break;

			case '>':
				if ( $result[ $attribute ] > $exception['VALUE'] ):
					$compare = TRUE;
				endif;
				break;

			case '>=':
				if ( $result[ $attribute ] >= $exception['VALUE'] ):
					$compare = TRUE;
				endif;
				break;

			case 'BETWEEN':
				if ( count( $exception['VALUE'] ) == 2 ):
					if (( (int)$result[ $attribute ] > (int)$exception['VALUE'][0] )
					&&	( (int)$result[ $attribute ] < (int)$exception['VALUE'][1] )):
						$compare = TRUE;
					endif;
				endif;
				break;

			case 'IN':
				if ( in_array( $result[ $attribute ], $exception['VALUE'] ) == TRUE ):
					$compare = TRUE;
				endif;
				break;

			default:
				if ( $result[ $attribute ] == $exception['VALUE'] ):
					$compare = TRUE;
				endif;
				break;

			endswitch;
		endswitch;

		// compare matches
		if ( $compare == TRUE ):
			// init disable/hide counter
			$disable_count = 0;

			// disable/hide the page
			if ( array_key_exists( 'SELECTION', $exception ) == TRUE ):
				if ( $exception['SELECTION'] == "HIDE" ):
					$exception['SECTIONS'] = "HIDE";	// do not add section data
					$exception['SUBTREE']  = "HIDE";	// do not show sub-pages
					$exception['ERROR']    = '';		// do not add mesages

					// increase disable/hide counter
					$disable_count = 1;
				elseif ( $exception['SELECTION'] == "DISABLED" ):
					$references[ $key ]['disabled']  = 'disabled="disabled"';

					// increase disable/hide counter
					$disable_count = 1;
				endif;
			endif;

			// hide sections
			if ( array_key_exists( 'SECTIONS', $exception ) == TRUE ):
				if ( $exception['SECTIONS'] == "HIDE" ):
					$showSections = FALSE;	// do not add section data
				endif;
			endif;

			// hide subtree
			if ( array_key_exists( 'SUBTREE', $exception ) == TRUE ):
				if ( $exception['SUBTREE'] == "HIDE" ):
					$subtreeParent = '';		// do not show sub-pages
				endif;
			endif;

			// add error if exists
			if ( array_key_exists( 'ERROR', $exception ) == TRUE ):
				if (( strlen( $exception['ERROR'] ) > 0 )
				&&	( array_key_exists( $exception['ERROR'], $MOD_CONTENT_COLLECTOR ) == TRUE )):
					$references[ $key ]['data'] .= $MOD_CONTENT_COLLECTOR[ $exception['ERROR'] ];
				endif;
			endif;

			// remove the data
			if ( array_key_exists( 'SELECTION', $exception ) == TRUE ):
				if ( $exception['SELECTION'] == "HIDE" ):
					unset( $references[ $key ] );
				endif;
			endif;

			// check number of disabled/hidden elements for related parent.
			// if all childs of a parent are disabled/hidden, disable parent too
			if ( array_key_exists( $key, $references ) == TRUE ):
				if ( array_key_exists( 'parent_key', $references[ $key ]) == TRUE ):
					// get page key on section validation only
					$parent_key = $references[ $key ]['parent_key'];

					// get existing disabled or hidden sections and increase the count
					$i = 0;
					if ( array_key_exists( 'parent_disabled', $references[ $parent_key ] ) == TRUE ):
						$i = $references[ $parent_key ]['parent_disabled'];
					endif;
					$references[ $parent_key ]['parent_disabled'] = $i + $disable_count;

					// get total number of already processed sections
					$parent_count = 0;
					if ( array_key_exists( 'parent_count', $references[ $parent_key ] ) == TRUE ):
						$parent_count = $references[ $parent_key ]['parent_count'];
					endif;

					// compare number of disabled sections with totalnumber of sections
					if (( $references[ $parent_key ]['parent_disabled'] > 0 )
					&&	( $references[ $parent_key ]['parent_disabled'] >= $parent_count )):
						$references[ $parent_key ]['disabled']  = 'disabled="disabled"';
					endif;
				endif;
			endif;

			// break the exception loop on first match
			break;
		endif;

	endforeach;
}

?>
