<?php

/**
 * collect content from all following pages from a defined start page onwards
 *
 * @module          content_collector
 * @author          Wolfgang Studer
 * @copyright       2015-2015 Wolfgang Studer
 * @link            www.LEPTON-cms.org
 * @license         GNU General Public License
 * @license_terms   please see info.php of this module
 * @version         $Id: 2.00.000 | 2015-11-29
 */

// include class.secure.php to protect this file and the whole CMS!
if ( defined('LEPTON_PATH') == TRUE ):	
	include(LEPTON_PATH.'/framework/class.secure.php');
else:
	$oneback = "../";
	$root = $oneback;
	$level = 1;
	while (($level < 10) && (!file_exists($root.'/framework/class.secure.php'))):
		$root .= $oneback;
		$level += 1;
	endwhile;
	
	if (file_exists($root.'/framework/class.secure.php')):
		include($root.'/framework/class.secure.php');
	else:
		trigger_error(sprintf("[ <b>%s</b> ] Can't include class.secure.php!", $_SERVER['SCRIPT_NAME']), E_USER_ERROR);
	endif;
endif;
// end include class.secure.php


// initialize the processing flag
	$loadPageContent = TRUE;

// define frontend Path
	$frontendPath = LEPTON_PATH . '/templates/' . TEMPLATE . '/frontend/content_collector/';

// get the configuration for current page section
	$query = 'SELECT `section_id`, `page_id`, `start_from_page`, `run_with_menu`
					, `addon_page_start`, `addon_section_start`, `addon_section_end`, `addon_page_end`
					, `in_ex_clude`, `in_ex_clude_list`
				FROM ' . TABLE_PREFIX . 'mod_content_collector
				WHERE section_id = ' . $section_id ;

	$query_data = $database->query($query);
	if ( $query_data->numRows() > 0 ):
		$result = $query_data->fetchRow();
	
		$start_from_page		= $result["start_from_page"];
		$run_with_menu			= $result["run_with_menu"];
		$addon_page_start		= $result["addon_page_start"];
		$addon_section_start	= $result["addon_section_start"];
		$addon_section_end		= $result["addon_section_end"];
		$addon_page_end			= $result["addon_page_end"];
		$in_ex_clude			= $result["in_ex_clude"];
		$in_ex_clude_list		= $result["in_ex_clude_list"];

		// is something refered ?
		if ( is_numeric( $start_from_page ) == FALSE ):
			$loadPageContent = FALSE;
		elseif ( $start_from_page < 0 ):
			$loadPageContent = FALSE;
		endif;
	else:
		$loadPageContent = FALSE;
	endif;

// get the content
	if ( $loadPageContent == TRUE ):
		// save current sectionID
		$section_id_orig = $section_id;

		// get all pages as array
		$pages = array();
		$pages = explode(",", show_menu2($run_with_menu, $start_from_page, SM2_ALL, SM2_ALL|SM2_ALLINFO|SM2_BUFFER, '[page_id],', '', '', '') );

		// add also starting page to array but on first position
		array_splice( $pages, 0, 0, $start_from_page);

		// define placeholder array
		$placeholders = array();
		$page_modified_by = '';
		// load default include on general level
		$include = LEPTON_PATH . '/modules/content_collector/lib/lib.placeholder.general.php';
		include( $include );
		// load additional include on general level in frontend template folder if exists
		$include =  $frontendPath . '/lib/lib.placeholder.general.php';
		if ( file_exists( $include ) == TRUE ):
			include( $include );
		endif;

		// loop over pages list
		foreach ( $pages as $content_page_id ):

			// check if pages are to be processed
			if (( $in_ex_clude == 'E' ) && ( strpos( $in_ex_clude_list, ':P' . $content_page_id . ':' ) !== false )):
				// page is to be excluded because it is defined in list
				continue;	// read next page

			elseif (( $in_ex_clude == 'I' ) && ( strpos( $in_ex_clude_list, ':P' . $content_page_id . ':' ) === false )):
				// page is to be excluded because it is NOT defined in list
				continue;	// read next page
			endif;

			// get the section details
			$query = 'SELECT s.module, s.section_id, s.name as section_name, p.*
						FROM ' . TABLE_PREFIX . 'sections s
						JOIN ' . TABLE_PREFIX . 'pages p on s.page_id = p.page_id
						WHERE s.page_id = "' . $content_page_id . '"
						  AND s.section_id <> ' . $section_id_orig .'
						  AND s.module != "content_collector"
						  AND s.module != "menu_link"
						  AND ((' . $now . ' BETWEEN s.publ_start AND s.publ_end )
						    OR (' . $now . ' >       s.publ_start AND s.publ_end = 0 ))
						ORDER BY s.position ASC';

			$query_data = $database->query($query);
			if ( $query_data->numRows() > 0 ):
				// initialize page content array
				$content = array();

				$addon_page_start_done = FALSE;
				$addon_page_end_tbd = FALSE;

				// init placeholders on page level on each new page
				$placeholders[ '#PAGE_ID#' ] = '';

				// loop over all sections found
				while( $result = $query_data->fetchRow() ):

					// check if sections are to be processed
					if (( $in_ex_clude == 'E' ) && ( strpos( $in_ex_clude_list, ':S' . $result['section_id'] . ':' ) !== false )):
						// section is to be excluded because it is defined in list
						continue;	// read next section

					elseif (( $in_ex_clude == 'I' ) && ( strpos( $in_ex_clude_list, ':S' . $result['section_id'] . ':' ) === false )):
						// page is to be excluded because it is NOT defined in list
						continue;	// read next section
					endif;

					// get module of refered section
					$module  = $result['module'];

					// check if section module is available
					$moduleView = LEPTON_PATH . '/modules/' . $module . '/view.php';
					if ( file_exists( $moduleView ) == TRUE ):

						// load the page content
						// assign section ID variable
						$section_id = $result['section_id'];

						// switch off output
						ob_start();

						// execute the refered module
						require( $moduleView );

						// save generated output
						$itemContent = ob_get_contents();
						ob_end_clean();

						// print content
						if ( strlen( $itemContent ) > 0 ):

							if ( $placeholders[ '#PAGE_ID#' ] == '' ):
								// load default include on page level
								$include = LEPTON_PATH . '/modules/content_collector/lib/lib.placeholder.page.php';
								include( $include );
								// load additional include on page level in frontend template folder if exists
								$include =  $frontendPath . '/lib/lib.placeholder.page.php';
								if ( file_exists( $include ) == TRUE ):
									include( $include );
								endif;
							endif;

							// load default include on section level
							$include = LEPTON_PATH . '/modules/content_collector/lib/lib.placeholder.section.php';
							include( $include );
							// load additional include on section level in frontend template folder if exists
							$include =  $frontendPath . '/lib/lib.placeholder.section.php';
							if ( file_exists( $include ) == TRUE ):
								include( $include );
							endif;

							// init output
							$output = '';

							// print page start addon
							if (( strlen( $addon_page_start ) > 0 ) && ( $addon_page_start_done == FALSE )):
								$output .= $addon_page_start . PHP_EOL;
								$addon_page_start_done = TRUE;
								$addon_page_end_tbd = TRUE;
							endif;

							// print section start addon
							if (( strlen( $addon_section_start ) > 0 )):
								$output .= $addon_section_start . PHP_EOL;
							endif;

							// print section content
							$output .= $itemContent . PHP_EOL;

							// print section end addon
							if (( strlen( $addon_section_end ) > 0 )):
								$output .= $addon_section_end . PHP_EOL;
							endif;

							// replace paceholders on output
							echo str_ireplace( array_keys($placeholders), array_values($placeholders), $output );
						endif;
					endif;

				endwhile;	// end loop over sections

				// check if page content array has a content. If yes, wrap - if exists - with HTML Code from settings
				if (( strlen( $addon_page_end ) > 0 ) && ( $addon_page_end_tbd == TRUE )):
					echo str_ireplace( array_keys($placeholders), array_values($placeholders), $addon_page_end ) . PHP_EOL;
					$addon_page_end_tbd = FALSE;
				endif;
			endif;	// endif data found
		endforeach;	// end loop pages array

	// restore origin sectionID
	$section_id = $section_id_orig;

	endif;
?>
